from os.path import expanduser, join

CONFIGURATION_DIRECTORY = join(expanduser('~'), '.guet')
